@@ -23,6 +23,9 @@ const GObject = imports.gi.GObject;
 const Geocode = imports.gi.GeocodeGlib;
 const Lang = imports.lang;
 
+const Application = imports.application;
+const PlaceStore = imports.placeStore;
+
 const Transportation = {
     CAR:        0,
     BIKE:       1,
@@ -105,6 +108,10 @@ const RouteQuery = new Lang.Class({
         });
     },
 
+    get latest() {
+        return this._latest;
+    },
+
     _init: function(args) {
         this.parent(args);
         this._points = [];
@@ -119,17 +126,27 @@ const RouteQuery = new Lang.Class({
 
         this._points.splice(index, 0, point);
         point.connect('notify::place', (function() {
+            let placeStore = Application.placeStore;
+            if (point.place) {
+                if (!placeStore.exists(point.place, null)) {
+                    placeStore.addPlace(point.place,
+                                        PlaceStore.PlaceType.RECENT);
+                }
+            }
             this.notify('points');
+            this._latest = point;
         }).bind(this));
+        this._latest = point;
         this.notify('points');
         this.emit('point-added', point, index);
-
         return point;
     },
 
     removePoint: function(index) {
         let removedPoints = this._points.splice(index, 1);
         let point = removedPoints ? removedPoints[0] : null;
+        if (point === this._latest)
+            this._latest = null;
 
         if (point) {
             this.notify('points');
@@ -152,6 +169,7 @@ const RouteQuery = new Lang.Class({
         this._points.forEach(function(point) {
             point.place = null;
         });
+        this._latest = null;
         this.thaw_notify();
         this.emit('reset');
     },
